# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_vpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_vpc.proto\x12\x13oak9.tython.gcp.vpc\x1a\x13shared/shared.proto\"=\n\x1bVpcAccessConnectorXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xc6\x02\n\x12VpcAccessConnector\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rip_cidr_range\x18\x02 \x01(\t\x12\x16\n\x0emax_throughput\x18\x03 \x01(\x01\x12\x16\n\x0emin_throughput\x18\x04 \x01(\x01\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07network\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12\r\n\x05state\x18\n \x01(\t\x12\x42\n\x08timeouts\x18\x0b \x01(\x0b\x32\x30.oak9.tython.gcp.vpc.VpcAccessConnectorXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_vpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VPCACCESSCONNECTORXTIMEOUTS._serialized_start=63
  _VPCACCESSCONNECTORXTIMEOUTS._serialized_end=124
  _VPCACCESSCONNECTOR._serialized_start=127
  _VPCACCESSCONNECTOR._serialized_end=453
# @@protoc_insertion_point(module_scope)
